@@ -20,5 +20,10 @@ class dc_tanf_countable_income(Variable):
                 "dc_tanf_countable_unearned_income",
             ],
         )
+        # Exclude income from GAC, this only applies when the child in household is unrelated to
+        # the head or spouse
+        gac_countable_income = spm_unit("dc_gac_countable_income", period)
         childcare_deduction = spm_unit("dc_tanf_childcare_deduction", period)
-        return max_(income_sources - childcare_deduction, 0)
+        return max_(
+            income_sources - gac_countable_income - childcare_deduction, 0
+        )
